@@ -75,8 +75,8 @@ class test_empty(unittest.TestCase):
         self.assertEqual( len(pCAPs), len(pCAPs_b) )
         self.assertTrue( pCAPs_b.circular )
         self.assertTrue( eq(pCAPs, pCAPs_b) )
-        pCAPs_b.linear = True
-        self.assertTrue( eq(pCAPs, pCAPs_b, circular=True) )
+        pCAPs_b_linear = pCAPs_b.tolinear()
+        self.assertTrue( eq(pCAPs, pCAPs_b_linear, circular=True) )
         pCAPs_c = pCAPs[200:]+pCAPs[:200]
         self.assertTrue( eq(pCAPs, pCAPs_c, circular=True) )
         with self.assertRaisesRegexp(ValueError, "shift"):
@@ -88,7 +88,9 @@ class test_empty(unittest.TestCase):
         from Bio.Seq import reverse_complement
 
         pcaps = read("./pCAPs.gb")
+        self.assertTrue(pcaps.circular == True)
         pcaps2 = sync(pcaps, "tctgacacatgcagctcccggagacggtcac")
+        self.assertTrue(pcaps2.circular == True)
         self.assertTrue( pcaps2.seq.watson.lower().startswith("tctgacacatgcagctcccggagacggtcac"))
         pcaps2 = sync(pcaps, "agaaaccattattatcatgacattaacctataaaaa")
         self.assertTrue(   str(pcaps2.seq).lower().startswith("agaaaccattattatcatgacattaacctataaaaa"))
@@ -102,17 +104,26 @@ class test_empty(unittest.TestCase):
         plasmid2 = sync(plasmid, pcaps)
         self.assertEqual( str(plasmid2[:10].seq).upper(), "TCGCGCGTTT")
 
+        a=read("./pUC19.gb")
+
+        a=a.synced("cggtgatgacggtgaaaacctctgacacat")
+
+        self.assertEqual(str(a.seq[0:60]), "CGGTGATGACGGTGAAAACCTCTGACACATGCAGCTCCCGGAGACGGTCACAGCTTGTCT")
+
+
+
+
+
     def test_copy_features(self):
 
         from Bio.SeqUtils.CheckSum import seguid
         from pydna import read,copy_features
         a=read("./pCAPs.gb")
         b=read("./pCAPs_fasta.txt")
-        b.circular=True
+        b=b.looped()
 
         for sh in [1,2,3,3127,3128,3129]:
-            newb = b[sh:]+b[:sh]
-            newb.circular=True
+            newb = (b[sh:]+b[:sh]).looped()
             copy_features(a, newb)
             self.assertTrue( sorted([f.extract(a).seq.tostring().lower() for f in a.features if len(f)>10],key=len) == sorted([f.extract(newb).seq.tostring().lower() for f in newb.features],key=len))
 
@@ -125,43 +136,44 @@ class test_empty(unittest.TestCase):
 
         seguid_bla = "riT98j2v4NxVS8sbw/Q8epCwQwo"
         seguid_cre = "xLZ2xs2O8CUMmWh2OrhmNFp5ZLg"
-        b.circular=False
+
         copy_features(a, b)
         assert [seguid(f.extract(b).seq) for f in b.features] == [seguid_cre,seguid_cre,seguid_bla,seguid_bla]
 
-        b=read("./pCAPs_fasta.txt")
+        b=read("./pCAPs_fasta.txt").looped()
+
         b=sync(b,"attaacgagtgccgtaaacgacgatggttttacc")
-        b.circular=False
+
         copy_features(a, b)
         assert [seguid(f.extract(b).seq) for f in b.features] == [seguid_cre,seguid_cre,seguid_bla,seguid_bla]
 
-        b=read("./pCAPs_fasta.txt")
+        b=read("./pCAPs_fasta.txt").looped()
         b=sync(b,"ttaacgagtgccgtaaacgacgatggttttacc")
-        b.circular=False
+
         copy_features(a, b)
         assert [seguid(f.extract(b).seq) for f in b.features] == [seguid_cre,seguid_cre,seguid_bla,seguid_bla]
 
-        b=read("./pCAPs_fasta.txt")
+        b=read("./pCAPs_fasta.txt").looped()
         b=sync(b,"taacgagtgccgtaaacgacgatggttttacc")
-        b.circular=False
+
         copy_features(a, b)
         assert [seguid(f.extract(b).seq) for f in b.features] == [seguid_bla,seguid_bla]
 
-        b=read("./pCAPs_fasta.txt")
+        b=read("./pCAPs_fasta.txt").looped()
         b=sync(b,"gttaccaatgcttaatcagtgaggcacctatctcagc")
-        b.circular=False
+
         copy_features(a, b)
         assert [seguid(f.extract(b).seq) for f in b.features] == [seguid_cre,seguid_cre,seguid_bla,seguid_bla]
 
-        b=read("./pCAPs_fasta.txt")
+        b=read("./pCAPs_fasta.txt").looped()
         b=sync(b,"ttaccaatgcttaatcagtgaggcacctatctcagc")
-        b.circular=False
+
         copy_features(a, b)
         assert [seguid(f.extract(b).seq) for f in b.features] == [seguid_cre,seguid_cre,seguid_bla,seguid_bla]
 
-        b=read("./pCAPs_fasta.txt")
+        b=read("./pCAPs_fasta.txt").looped()
         b=sync(b,"taccaatgcttaatcagtgaggcacctatctcagc")
-        b.circular=False
+
         copy_features(a, b)
         assert [seguid(f.extract(b).seq) for f in b.features] == [seguid_cre,seguid_cre,]
 
